@@ -30,7 +30,7 @@ SOURCE = """
 source!%(src_num)d!type = interpreter
 source!%(src_num)d!nick = uWSGI %(src_num)d
 source!%(src_num)d!host = /tmp/cherokee-source%(src_num)d.sock
-source!%(src_num)d!interpreter = %(uwsgi_binary)s -s /tmp/cherokee-source%(src_num)d.sock -t 10 -M -p 1 -C %(uwsgi_extra)s
+source!%(src_num)d!interpreter = %(uwsgi_binary)s -s 127.0.0.1:%(src_port)d -t 10 -M -p 1 -C %(uwsgi_extra)s
 """
 
 SOURCE_XML   = """ -x %s"""
@@ -192,6 +192,7 @@ class Wizard_VServer_uWSGI (WizardPage):
         # Locals
         vsrv_pre = cfg_vsrv_get_next (self._cfg)
         src_num, src_pre = cfg_source_get_next (self._cfg)
+        src_port = cfg_source_find_free_port ()
 
         # Usual Static files
         self._common_add_usual_static_files ("%s!rule!500" % (vsrv_pre))
@@ -266,6 +267,7 @@ class Wizard_Rules_uWSGI (WizardPage):
         # Locals
         rule_num, rule_pre = cfg_vsrv_rule_get_next (self._cfg, self._pre)
         src_num,  src_pre  = cfg_source_get_next (self._cfg)
+        src_port = cfg_source_find_free_port ()
 
         # Add the new rules
         config = CONFIG_RULES % (locals())
