@@ -133,20 +133,13 @@ cherokee_admin_server_reply_set_port_tls (cherokee_handler_admin_t *ahdl, cherok
 ret_t 
 cherokee_admin_server_reply_get_tx (cherokee_handler_admin_t *ahdl, cherokee_buffer_t *question, cherokee_buffer_t *reply)
 {
-	ret_t              ret;
-	size_t             rx, tx;
 	cherokee_server_t *srv = HANDLER_SRV(ahdl);
 
 	UNUSED(question);
 
-	ret = cherokee_server_get_total_traffic (srv, &rx, &tx);
-	if (unlikely (ret != ret_ok)) return ret;
-
-	ret = cherokee_buffer_add_str (reply, "server.tx is ");
-	if (unlikely (ret != ret_ok)) return ret;
-
-	ret = cherokee_buffer_add_fsize (reply, tx);
-	if (unlikely (ret != ret_ok)) return ret;
+	cherokee_buffer_add_str   (reply, "server.tx is ");
+	cherokee_buffer_add_fsize (reply, 
+				   (srv->collector) ? COLLECTOR_TX(srv->collector) : -1);
 
 	return ret_ok;
 }
@@ -155,20 +148,13 @@ cherokee_admin_server_reply_get_tx (cherokee_handler_admin_t *ahdl, cherokee_buf
 ret_t 
 cherokee_admin_server_reply_get_rx (cherokee_handler_admin_t *ahdl, cherokee_buffer_t *question, cherokee_buffer_t *reply)
 {
-	ret_t              ret;
-	size_t             rx, tx;
 	cherokee_server_t *srv = HANDLER_SRV(ahdl);
 
 	UNUSED(question);
 
-	ret = cherokee_server_get_total_traffic (srv, &rx, &tx);
-	if (unlikely (ret != ret_ok)) return ret;
-
-	ret = cherokee_buffer_add_str (reply, "server.rx is ");
-	if (unlikely (ret != ret_ok)) return ret;
-
-	ret = cherokee_buffer_add_fsize (reply, rx);
-	if (unlikely (ret != ret_ok)) return ret;
+	cherokee_buffer_add_str   (reply, "server.tx is ");
+	cherokee_buffer_add_fsize (reply, 
+				   (srv->collector) ? COLLECTOR_RX(srv->collector) : -1);
 
 	return ret_ok;
 }
