@@ -47,6 +47,7 @@ typedef enum {
 	header_authorization,
 	header_connection,
 	header_content_length,
+	header_content_type,
 	header_cookie,
 	header_host,
 	header_if_modified_since,
@@ -61,6 +62,8 @@ typedef enum {
 	header_user_agent,
 	header_x_forwarded_for,
 	header_x_forwarded_host,
+	header_x_real_ip,
+	header_expect,
 	HEADER_LENGTH
 } cherokee_common_header_t;
 
