@@ -180,9 +180,7 @@ cherokee_icons_add_suffix (cherokee_icons_t *icons, cherokee_buffer_t *icon, che
 
 	ret = cherokee_avl_add (&icons->suffixes, suffix, tmp);
 	if (unlikely (ret != ret_ok)) {
-		LOG_ERROR ("Duped suffix (case insensitive) '%s', pointing to '%s'\n",
-			   suffix->buf, tmp->buf);
-
+		LOG_ERROR (CHEROKEE_ERROR_ICONS_DUP_SUFFIX, suffix->buf, tmp->buf);
 		cherokee_buffer_free (tmp);
 		return ret_ok;
 	}
@@ -258,7 +256,7 @@ cherokee_icons_get_icon (cherokee_icons_t   *icons,
 		return ret_ok;
 	}
 
-	LOG_CRITICAL_S ("A default icons is needed\n");
+	LOG_CRITICAL_S (CHEROKEE_ERROR_ICONS_NO_DEFAULT);
 	return ret_error;
 }
 
@@ -290,7 +288,7 @@ add_suffix (char *file, void *data)
 
 	ret = cherokee_icons_add_suffix (icons, key, &file_buf);
 	if (ret != ret_ok) {
-		LOG_ERROR ("Couldn't assign suffix '%s' to file '%s'\n", file, key->buf);
+		LOG_ERROR (CHEROKEE_ERROR_ICONS_ASSIGN_SUFFIX, file, key->buf);
 		return ret_error;
 	}
 
