@@ -34,12 +34,8 @@
 
 typedef struct {
 	cherokee_logger_t         logger;
-
 	cherokee_template_t       template_conn;
-	cherokee_template_t       template_error;
-
 	cherokee_logger_writer_t *writer_access;
-	cherokee_logger_writer_t *writer_error;
 } cherokee_logger_custom_t;
 
 #define LOG_CUSTOM(x) ((cherokee_logger_custom_t *)(x))
@@ -50,10 +46,8 @@ ret_t cherokee_logger_custom_init             (cherokee_logger_custom_t *logger)
 
 ret_t cherokee_logger_custom_flush            (cherokee_logger_custom_t *logger);
 ret_t cherokee_logger_custom_reopen           (cherokee_logger_custom_t *logger);
-ret_t cherokee_logger_custom_get_error_writer (cherokee_logger_custom_t *logger, cherokee_logger_writer_t **writer);
 
 ret_t cherokee_logger_custom_write_access     (cherokee_logger_custom_t *logger, cherokee_connection_t *conn);
-ret_t cherokee_logger_custom_write_error      (cherokee_logger_custom_t *logger, cherokee_buffer_t *error);
 ret_t cherokee_logger_custom_write_string     (cherokee_logger_custom_t *logger, const char *string);
 
 #endif /* CHEROKEE_LOGGER_CUSTOM_H */
